@@ -38,15 +38,8 @@
 #ifndef DIAGNOSTICS__LIB_ANNOTATIONS__INCLUDE_GUARD
 #define DIAGNOSTICS__LIB_ANNOTATIONS__INCLUDE_GUARD
 
-#include <diagnostics/macros/check_annotation.hpp>
-#include <diagnostics/macros/assert_annotation.hpp>
-#include <diagnostics/macros/block_annotation.hpp>
-#include <diagnostics/macros/invariance_annotation.hpp>
-#include <diagnostics/macros/exceptionless_block_annotation.hpp>
-#include <diagnostics/macros/relation_modifier.hpp>
-
 #ifndef XXX_DEBUG__LEVEL__
-#  define XXX_DEBUG__LEVEL__ 2
+#  define XXX_DEBUG__LEVEL__ -1
 #endif
 
 /**
@@ -72,6 +65,16 @@
 #  define DEBUG__LEVEL__ XXX_DEBUG__LEVEL__
 #endif
 
+#if XXX_DEBUG__LEVEL__ >= 0
+#  include <diagnostics/macros/check_annotation.hpp>
+#  include <diagnostics/macros/assert_annotation.hpp>
+#  include <diagnostics/macros/block_annotation.hpp>
+#  include <diagnostics/macros/invariance_annotation.hpp>
+#  include <diagnostics/macros/exceptionless_block_annotation.hpp>
+#  include <diagnostics/macros/relation_modifier.hpp>
+#else
+#  define DIAGNOSTICS_RELATION(ARG1, ARG2, ARG3, ARG4, ARG5) ((void)0)
+#endif
 
 #ifndef XXX_INLINE
 #  if XXX_DEBUG__LEVEL__ == 0
@@ -83,13 +86,14 @@
 
 
 #ifndef XXX_BASE_EXCEPTION_TYPE
-#  define XXX_BASE_EXCEPTION_TYPE ::diagnostics::Exception
-#  include <diagnostics/frame/exception.hpp>
-#  define XXX_BASE_EXCEPTION_STR_WHAT(EX) (::std::string("EXCEPTION=\"") + (EX).name() + "\" WHAT=\"" + (EX).what() + "\"")
+#  define XXX_BASE_EXCEPTION_TYPE ::std::exception
+#  include <exception>
+#  define XXX_BASE_EXCEPTION_STR_WHAT(EX) (::std::string("EXCEPTION=\"") + "\" WHAT=\"" + (EX).what() + "\"")
 #endif
 
+
 #ifndef XXX_HANDLE_TEST_EXCEPTION_EXPLICITLY
-#  define XXX_HANDLE_TEST_EXCEPTION_EXPLICITLY 0
+#  define XXX_HANDLE_TEST_EXCEPTION_EXPLICITLY 1
 #endif
 
 
@@ -118,10 +122,11 @@
 
 // derived config
 
-
+#if XXX_DEBUG__LEVEL__ >= 0
 #if XXX_HANDLE_TEST_EXCEPTION_EXPLICITLY == 1
 #  include <diagnostics/unittest/test_exception.hpp>
 #endif
+#endif
 
 #ifndef XXX_BASE_EXCEPTION_STR_WHAT
 #  warning XXX_BASE_EXCEPTION_STR_WHAT not defined
@@ -143,6 +148,7 @@
 #  define XXX_AUDIT_BINARY_TRACE1(NR_WHAT,STR_WHAT) \
     DIAGNOSTICS_BASE_LOG(::diagnostics::LEVEL_AUDIT,::diagnostics::TYPE_TRACE_BINARY,(NR_WHAT),(STR_WHAT))
 
+
 #  define XXX_AUDIT_BLOCK_ENTER(STR_WHAT)  \
     DIAGNOSTICS_BASE_BLOCK_ENTER(::diagnostics::LEVEL_AUDIT, \
                                  ::diagnostics::TYPE_BLOCK_ENTER, \
@@ -236,7 +242,6 @@
                                               XXX_HANDLE_TEST_EXCEPTION_EXPLICITLY,\
                                               XXX_BASE_EXCEPTION_TYPE,\
                                               XXX_BASE_EXCEPTION_STR_WHAT)
-
 #  define XXX_AUDIT_EXEC(CMD) CMD
 #  define XXX_AUDIT_EXEC_ENTER do { ((void)0)
 #  define XXX_AUDIT_EXEC_EXIT  } while(false)
@@ -262,6 +267,8 @@
 
 #  define XXX_AUDIT_ASSERT(NAME,COND)           ((void)0)
 #  define XXX_AUDIT_ASSERT1(NAME,COND,STR_WHAT) ((void)0)
+#  define XXX_AUDIT_ASSERT_LOG(NAME,COND)           ((void)0)
+#  define XXX_AUDIT_ASSERT_LOG1(NAME,COND,STR_WHAT) ((void)0)
 #  define XXX_AUDIT_CHECK(NAME,COND)            ((void)0)
 #  define XXX_AUDIT_CHECK1(NAME,COND,STR_WHAT)  ((void)0)
 
@@ -425,6 +432,7 @@
 
 ////////////////////////////////////////////////////////////////////////////////
 
+#if XXX_DEBUG__LEVEL__ >= 0
 
 #define XXX_PROD_TRACE(STR_WHAT) \
     DIAGNOSTICS_BASE_LOG(::diagnostics::LEVEL_PROD,::diagnostics::TYPE_TRACE,XXX_NR_WHAT_DEFAULT,(STR_WHAT))
@@ -507,6 +515,41 @@
                                               XXX_BASE_EXCEPTION_TYPE,\
                                               XXX_BASE_EXCEPTION_STR_WHAT)
 
+#else
+
+#  define XXX_PROD_TRACE(STR_WHAT)        ((void)0)
+#  define XXX_PROD_BINARY_TRACE(STR_WHAT) ((void)0)
+
+#  define XXX_PROD_BLOCK_ENTER(STR_WHAT) do {
+#  define XXX_PROD_BLOCK_EXIT            } while(false)
+#  define XXX_PROD_BLOCK_GUARD(STR_WHAT) ((void)0)
+
+#  define XXX_PROD_PROCEDURE_ENTER(STR_WHAT) do {
+#  define XXX_PROD_PROCEDURE_EXIT            } while(false)
+#  define XXX_PROD_PROCEDURE_GUARD(STR_WHAT) ((void)0)
+
+#  define XXX_PROD_METHOD_ENTER(STR_WHAT) do {
+#  define XXX_PROD_METHOD_EXIT            } while(false)
+#  define XXX_PROD_METHOD_GUARD(STR_WHAT) ((void)0)
+
+#  define XXX_PROD_ASSERT(NAME,COND)           if( ! ( COND ) ) throw NAME ( #COND )
+#  define XXX_PROD_ASSERT1(NAME,COND,STR_WHAT) if( ! ( COND ) ) throw NAME ( STR_WHAT )
+
+#  define XXX_PROD_CLASS_THROWING_INVARIANCE_ENTER do {
+#  define XXX_PROD_CLASS_THROWING_INVARIANCE_EXIT  } while(false)
+
+#  define XXX_PROD_CLASS_INVARIANCE_GUARD ((void)0)
+#  define XXX_PROD_CLASS_INVARIANCE_ENTER do {
+#  define XXX_PROD_CLASS_INVARIANCE_EXIT  } while(false)
+
+#  define XXX_PROD_CLASS_INVARIANCE_ASSERT  ((void)0)
+
+
+#  define XXX_PROD_EXCEPTIONLESS_BLOCK_ENTER do {
+#  define XXX_PROD_EXCEPTIONLESS_BLOCK_EXIT  } while(false)
+
+#endif
+
 
 #if XXX_DEBUG__LEVEL__ > 0
 
